<?php 

$lang['module_name'] = 'Модуль кешування';

$lang['display_as'] = array(
    'name' => 'Сторінка',
    'cache' => 'Кешується'
);

$lang['Activate cache'] = 'Увімкнути';
$lang['Activate cache?'] = 'Увімкнути кеш для сторінки(ок)?';
$lang['Deactivate cache'] = 'Вимкнути';
$lang['Deactivate cache?'] = 'Вимкнути кеш для сторінки(ок)?';
$lang['Clear cache'] = 'Почистити кеш';
$lang['Clear cache?'] = 'Почистити кеш для сторінки(ок)?';